# 1.0.0-dev (in progress)
- Moved code from AZ Reporting Suite.
- Decoupled from SGE using iPython-cluster-helper (https://github.com/roryk/ipython-cluster-helper).
- New region coverage reports.
- Support FastQ and downsampling.